@@ -6,6 +6,8 @@ import environ
 import sys
 import os
 
+from ... import __version__
+
 ROOT_DIR = (
     environ.Path(__file__) - 3
 )
@@ -463,6 +465,11 @@ REST_FRAMEWORK = {
 
     "DEFAULT_SCHEMA_CLASS": "drf_spectacular.openapi.AutoSchema",
 }
+
+SPECTACULAR_SETTINGS = {
+    'VERSION': __version__,
+}
+
 # Your stuff...
 # ------------------------------------------------------------------------------
 
