@@ -395,9 +395,10 @@ class PasswordResetFromKeyView(DjangoSsoAppApiViewMixin, django_sso_app_views.Pa
 
             set_session_key(request, INTERNAL_RESET_SESSION_KEY, key)
 
-            _response = super(PasswordResetFromKeyView, self).post(request, uidb36, **kwargs)
+            _response = super(PasswordResetFromKeyView, self).post(request, uidb36, key, **kwargs)
 
         except:
+            logger.exception('Error while resetting password form key')
             return self.get_error_response()
 
         else:
