@@ -6,7 +6,7 @@ from .forms import UserChangeForm, UserCreationForm
 from ..profiles.models import Profile
 
 _list_display = ('username', 'email', 'is_staff', 'is_superuser', 'last_login', 'is_active', 'date_joined')
-_search_fields = ('username', 'email')
+_search_fields = ('username', 'email', 'sso_app_profile__sso_id')
 
 
 class ProfileInline(StackedInline):
