@@ -16,8 +16,9 @@ logger = logging.getLogger('django_sso_app.core.middleware')
 ADMIN_URL = '/{}'.format(settings.ADMIN_URL)
 PROFILE_INCOMPLETE_ENABLED_PATHS = [
     reverse('javascript-catalog'),
-    reverse('profile.complete'),
+    reverse('profile.complete')
 ]
+USER_TO_SUBSCRIBE_ENABLED_PATHS = PROFILE_INCOMPLETE_ENABLED_PATHS
 
 
 class DjangoSsoAppAuthenticationBaseMiddleware(MiddlewareMixin):
@@ -28,8 +29,10 @@ class DjangoSsoAppAuthenticationBaseMiddleware(MiddlewareMixin):
     # Name of request header to grab username from.  This will be the key as
     # used in the request.META dictionary, i.e. the normalization of headers to
     # all uppercase and the addition of "HTTP_" prefix apply.
-    header = app_settings.APIGATEWAY_CONSUMER_CUSTOM_ID_HEADER
-    anonymous_header = app_settings.APIGATEWAY_ANONYMOUS_CONSUMER_HEADER
+    consumer_id_header = app_settings.APIGATEWAY_CONSUMER_CUSTOM_ID_HEADER
+    anonymous_consumer_custom_ids = app_settings.APIGATEWAY_ANONYMOUS_CONSUMER_IDS
+    anonymous_consumer_header = app_settings.APIGATEWAY_ANONYMOUS_CONSUMER_HEADER
+    anonymous_consumer_header_value = app_settings.APIGATEWAY_ANONYMOUS_CONSUMER_HEADER_VALUE
 
     @staticmethod
     def _clear_response_jwt(request):
@@ -58,10 +61,19 @@ class DjangoSsoAppAuthenticationBaseMiddleware(MiddlewareMixin):
                 not (request_path.startswith('/media/')) and \
                 not (request_path.startswith('/logout/')) and \
                 not (request_path.startswith('/password/reset/')) and \
-                not (request_path.startswith('/api/v1/auth/users/') and request.method == 'PATCH') and \
-                not (request_path.startswith('/confirm-email/'))
+                not (request_path.startswith('/confirm-email/')) and \
+                not (request_path.startswith('/api/v1/'))  # keep api endpoints enabled
 
-                # not (request_path.startswith('/api/v1/')) and \
+    @staticmethod
+    def _request_path_is_disabled_for_users_to_subscribe(request):
+        request_path = request.path
+        return (request_path not in USER_TO_SUBSCRIBE_ENABLED_PATHS) and \
+                not (request_path.startswith('/static/')) and \
+                not (request_path.startswith('/media/')) and \
+                not (request_path.startswith('/logout/')) and \
+                not (request_path.startswith('/password/reset/')) and \
+                not (request_path.startswith('/confirm-email/')) and \
+                not (request_path.startswith('/api/v1/'))  # keep api endpoints enabled
 
     def process_request(self, request):
         raise NotImplementedError('process_request')
